##  Integration REST API
You can interact with the Integration API through REST API endpoints. For more information, see [Integration REST API](https://help.sap.com/docs/leanix/ea/integration-rest-api?locale=en-US&state=PRODUCTION&version=CLOUD "How to connect to the Integration API from an external system.").
